@@ -1,5 +1,3 @@
-from django.contrib.auth.models import Permission
-from django.contrib.contenttypes.models import ContentType
 from django.urls import include, path, reverse
 from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
@@ -8,7 +6,7 @@ from wagtail import hooks
 from wagtail.admin.menu import MenuItem
 from wagtail.snippets.bulk_actions.delete import DeleteBulkAction
 from wagtail.snippets.models import get_snippet_models
-from wagtail.snippets.permissions import user_can_edit_snippets
+from wagtail.snippets.permissions import user_can_access_snippets
 from wagtail.snippets.views import snippets as snippet_views
 
 
@@ -35,7 +33,7 @@ class SnippetsMenuItem(MenuItem):
         )
 
     def is_shown(self, request):
-        return not self._all_have_menu_items and user_can_edit_snippets(request.user)
+        return not self._all_have_menu_items and user_can_access_snippets(request.user)
 
 
 @hooks.register("register_admin_menu_item")
@@ -49,10 +47,4 @@ def register_snippets_menu_item():
     )
 
 
-@hooks.register("register_permissions")
-def register_permissions():
-    content_types = ContentType.objects.get_for_models(*get_snippet_models()).values()
-    return Permission.objects.filter(content_type__in=content_types)
-
-
 hooks.register("register_bulk_action", DeleteBulkAction)
