@@ -28,45 +28,46 @@ from wagtail.test.testapp.models import (
 
 class TestCreateOrUpdateForObject(TestCase):
     def setUp(self):
-        image_model = get_image_model()
-        self.image_content_type = ContentType.objects.get_for_model(image_model)
+        with self.captureOnCommitCallbacks(execute=True):
+            image_model = get_image_model()
+            self.image_content_type = ContentType.objects.get_for_model(image_model)
 
-        self.test_feed_image = image_model.objects.create(
-            title="Test feed image",
-            file=get_test_image_file(),
-        )
-        self.test_image_1 = image_model.objects.create(
-            title="Test image 1",
-            file=get_test_image_file(),
-        )
-        self.test_image_2 = image_model.objects.create(
-            title="Test image 2",
-            file=get_test_image_file(),
-        )
+            self.test_feed_image = image_model.objects.create(
+                title="Test feed image",
+                file=get_test_image_file(),
+            )
+            self.test_image_1 = image_model.objects.create(
+                title="Test image 1",
+                file=get_test_image_file(),
+            )
+            self.test_image_2 = image_model.objects.create(
+                title="Test image 2",
+                file=get_test_image_file(),
+            )
 
-        # Add event page
-        self.event_page = EventPage(
-            title="Event page",
-            slug="event-page",
-            location="the moon",
-            audience="public",
-            cost="free",
-            date_from="2001-01-01",
-            feed_image=self.test_feed_image,
-        )
-        self.event_page.carousel_items = [
-            EventPageCarouselItem(
-                caption="1234567", image=self.test_image_1, sort_order=1
-            ),
-            EventPageCarouselItem(
-                caption="7654321", image=self.test_image_2, sort_order=2
-            ),
-            EventPageCarouselItem(
-                caption="abcdefg", image=self.test_image_1, sort_order=3
-            ),
-        ]
-        self.root_page = Page.objects.get(id=2)
-        self.root_page.add_child(instance=self.event_page)
+            # Add event page
+            self.event_page = EventPage(
+                title="Event page",
+                slug="event-page",
+                location="the moon",
+                audience="public",
+                cost="free",
+                date_from="2001-01-01",
+                feed_image=self.test_feed_image,
+            )
+            self.event_page.carousel_items = [
+                EventPageCarouselItem(
+                    caption="1234567", image=self.test_image_1, sort_order=1
+                ),
+                EventPageCarouselItem(
+                    caption="7654321", image=self.test_image_2, sort_order=2
+                ),
+                EventPageCarouselItem(
+                    caption="abcdefg", image=self.test_image_1, sort_order=3
+                ),
+            ]
+            self.root_page = Page.objects.get(id=2)
+            self.root_page.add_child(instance=self.event_page)
 
         self.expected_references = {
             (
@@ -168,8 +169,9 @@ class TestCreateOrUpdateForObject(TestCase):
         )
 
     def test_saving_base_model_does_not_remove_references(self):
-        page = Page.objects.get(pk=self.event_page.pk)
-        page.save()
+        with self.captureOnCommitCallbacks(execute=True):
+            page = Page.objects.get(pk=self.event_page.pk)
+            page.save()
         self.assertSetEqual(
             set(
                 ReferenceIndex.get_references_for_object(self.event_page).values_list(
@@ -180,11 +182,12 @@ class TestCreateOrUpdateForObject(TestCase):
         )
 
     def test_null_parental_key(self):
-        obj = ModelWithNullableParentalKey(
-            content="""<p><a linktype="page" id="%d">event page</a></p>"""
-            % self.event_page.id
-        )
-        obj.save()
+        with self.captureOnCommitCallbacks(execute=True):
+            obj = ModelWithNullableParentalKey(
+                content="""<p><a linktype="page" id="%d">event page</a></p>"""
+                % self.event_page.id
+            )
+            obj.save()
 
         # Models with a ParentalKey are not considered indexable - references are recorded against the parent model
         # instead. Since the ParentalKey is null here, no reference will be recorded.
@@ -192,56 +195,74 @@ class TestCreateOrUpdateForObject(TestCase):
         self.assertEqual(refs.count(), 0)
 
     def test_lazy_parental_key(self):
-        event_page_related_link = EventPageRelatedLink()
-        # The parent model is a lazy object
-        event_page_related_link.page = SimpleLazyObject(lambda: self.event_page)
-        event_page_related_link.link_page = self.root_page
-        event_page_related_link.save()
+        with self.captureOnCommitCallbacks(execute=True):
+            event_page_related_link = EventPageRelatedLink()
+            # The parent model is a lazy object
+            event_page_related_link.page = SimpleLazyObject(lambda: self.event_page)
+            event_page_related_link.link_page = self.root_page
+            event_page_related_link.save()
         refs = ReferenceIndex.get_references_to(self.root_page)
         self.assertEqual(refs.count(), 1)
 
     def test_generic_foreign_key(self):
-        page1 = GenericSnippetPage(
-            title="generic snippet page", snippet_content_object=self.event_page
-        )
-        self.root_page.add_child(instance=page1)
-        page2 = GenericSnippetPage(
-            title="generic snippet page", snippet_content_object=None
-        )
-        self.root_page.add_child(instance=page2)
+        with self.captureOnCommitCallbacks(execute=True):
+            page1 = GenericSnippetPage(
+                title="generic snippet page", snippet_content_object=self.event_page
+            )
+            self.root_page.add_child(instance=page1)
+            page2 = GenericSnippetPage(
+                title="generic snippet page", snippet_content_object=None
+            )
+            self.root_page.add_child(instance=page2)
 
         refs = ReferenceIndex.get_references_to(self.event_page)
         self.assertEqual(refs.count(), 1)
 
     def test_model_index_ignore_generic_foreign_key(self):
-        page1 = GenericSnippetNoIndexPage(
-            title="generic snippet page", snippet_content_object=self.event_page
-        )
-        self.root_page.add_child(instance=page1)
-        page2 = GenericSnippetNoIndexPage(
-            title="generic snippet page", snippet_content_object=None
-        )
-        self.root_page.add_child(instance=page2)
+        with self.captureOnCommitCallbacks(execute=True):
+            page1 = GenericSnippetNoIndexPage(
+                title="generic snippet page", snippet_content_object=self.event_page
+            )
+            self.root_page.add_child(instance=page1)
+            page2 = GenericSnippetNoIndexPage(
+                title="generic snippet page", snippet_content_object=None
+            )
+            self.root_page.add_child(instance=page2)
 
         # There should be no references
         refs = ReferenceIndex.get_references_to(self.event_page)
         self.assertEqual(refs.count(), 0)
 
     def test_model_field_index_ignore_generic_foreign_key(self):
-        content_type = ContentType.objects.get_for_model(self.event_page)
-        page1 = GenericSnippetNoFieldIndexPage(
-            title="generic snippet page", snippet_content_type_nonindexed=content_type
-        )
-        self.root_page.add_child(instance=page1)
-        page2 = GenericSnippetNoFieldIndexPage(
-            title="generic snippet page", snippet_content_type_nonindexed=None
-        )
-        self.root_page.add_child(instance=page2)
+        with self.captureOnCommitCallbacks(execute=True):
+            content_type = ContentType.objects.get_for_model(self.event_page)
+            page1 = GenericSnippetNoFieldIndexPage(
+                title="generic snippet page",
+                snippet_content_type_nonindexed=content_type,
+            )
+            self.root_page.add_child(instance=page1)
+            page2 = GenericSnippetNoFieldIndexPage(
+                title="generic snippet page", snippet_content_type_nonindexed=None
+            )
+            self.root_page.add_child(instance=page2)
 
         # There should be no references
         refs = ReferenceIndex.get_references_to(content_type)
         self.assertEqual(refs.count(), 0)
 
+    def test_model_with_uuid_primary_key(self):
+        refs = ReferenceIndex.get_references_to(self.event_page)
+        self.assertEqual(refs.count(), 0)
+
+        with self.captureOnCommitCallbacks(execute=True):
+            AdvertWithCustomUUIDPrimaryKey.objects.create(
+                text="An advertisement",
+                page=self.event_page,
+            )
+
+        refs = ReferenceIndex.get_references_to(self.event_page)
+        self.assertEqual(refs.count(), 1)
+
     def test_rebuild_references_index_no_verbosity(self):
         stdout = StringIO()
         management.call_command(
@@ -449,7 +470,8 @@ class TestDescribeOnDelete(TestCase):
                 if "on_delete_set_default" not in init_kwargs:
                     init_kwargs["on_delete_set_default"] = None
 
-                obj = VariousOnDeleteModel.objects.create(**init_kwargs)
+                with self.captureOnCommitCallbacks(execute=True):
+                    obj = VariousOnDeleteModel.objects.create(**init_kwargs)
                 usage = ReferenceIndex.get_references_to(
                     referred_object
                 ).group_by_source_object()
